@@ -25,7 +25,7 @@
 #include <string.h>
 #include <glib/garray.h>
 #include <libgnome/gnome-i18n.h>
-#include <e-util/e-time-utils.h>
+#include <libedataserver/e-time-utils.h>
 #include <libecal/e-cal-time-util.h>
 #include "comp-util.h"
 #include "e-cal-model.h"
@@ -108,7 +108,7 @@ enum {
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE (ECalModel, e_cal_model, E_TABLE_MODEL_TYPE);
+G_DEFINE_TYPE (ECalModel, e_cal_model, E_TABLE_MODEL_TYPE)
 
 static void
 e_cal_model_class_init (ECalModelClass *klass)
@@ -326,8 +326,6 @@ get_classification (ECalModelComponent *comp_data)
 	default:
 		return _("Unknown");
 	}
-
-	return _("Unknown");
 }
 
 static const char *
@@ -944,7 +942,6 @@ ecm_get_color_for_component (ECalModel *model, ECalModelComponent *comp_data)
 {
 	ESource *source;
 	guint32 source_color;
-	ECalModelPrivate *priv;
 	gint i, first_empty = 0;
 	static AssignedColorData assigned_colors[] = {
 		{ "#BECEDD", NULL }, /* 190 206 221     Blue */
@@ -961,8 +958,6 @@ ecm_get_color_for_component (ECalModel *model, ECalModelComponent *comp_data)
 
 	g_return_val_if_fail (E_IS_CAL_MODEL (model), NULL);
 
-	priv = model->priv;
-             
 	source = e_cal_get_source (comp_data->client);
 	if (e_source_get_color (source, &source_color)) {
 		g_free (comp_data->color);
@@ -1168,8 +1163,6 @@ e_cal_model_set_default_client (ECalModel *model, ECal *client)
 	priv = model->priv;
 
 	if (priv->default_client) {
-		ECalModelClient *client_data;
-		
 		client_data = find_client_data (model, priv->default_client);
 		g_assert (client_data);
 
@@ -1244,7 +1237,6 @@ find_client_data (ECalModel *model, ECal *client)
 	return NULL;
 }
 
-/* FIXME how do we prevent the same UID is different calendars? */
 static ECalModelComponent *
 search_by_id_and_client (ECalModelPrivate *priv, ECal *client, const ECalComponentId *id)
 {
@@ -1288,11 +1280,32 @@ add_instance_cb (ECalComponent *comp, time_t instance_start, time_t instance_end
 	ECalModelComponent *comp_data;
 	ECalModelPrivate *priv;
 	RecurrenceExpansionData *rdata = user_data;
+	icaltimetype time;
+	ECalComponentDateTime datetime, to_set;
+	icaltimezone *zone = NULL;
+
+	g_return_val_if_fail (E_IS_CAL_COMPONENT (comp), TRUE);
 
 	priv = rdata->model->priv;
 
 	e_table_model_pre_change (E_TABLE_MODEL (rdata->model));
 
+	/* set the right instance start date to component */
+	e_cal_component_get_dtstart (comp, &datetime);
+	e_cal_get_timezone (rdata->client, datetime.tzid, &zone, NULL);
+	time = icaltime_from_timet_with_zone (instance_start, FALSE, zone ? zone : priv->zone);
+	to_set.value = &time;
+	to_set.tzid = datetime.tzid; 
+	e_cal_component_set_dtstart (comp, &to_set);
+	
+	/* set the right instance end date to component*/
+	e_cal_component_get_dtend (comp, &datetime);
+	e_cal_get_timezone (rdata->client, datetime.tzid, &zone, NULL);
+	time = icaltime_from_timet_with_zone (instance_end, FALSE, zone ? zone : priv->zone);
+	to_set.value = &time;
+	to_set.tzid = datetime.tzid; 
+	e_cal_component_set_dtend (comp, &to_set);
+
 	comp_data = g_new0 (ECalModelComponent, 1);
 	comp_data->client = g_object_ref (rdata->client);
 	comp_data->icalcomp = icalcomponent_new_clone (e_cal_component_get_icalcomponent (comp));
@@ -1344,20 +1357,21 @@ e_cal_view_objects_added_cb (ECalView *query, GList *objects, gpointer user_data
 		ECalModelComponent *comp_data;
 		ECalComponentId *id;
 		ECalComponent *comp = e_cal_component_new ();
+		ECal *client = e_cal_view_get_client (query);
 
 		e_cal_component_set_icalcomponent (comp, icalcomponent_new_clone (l->data));
 		id = e_cal_component_get_id (comp);
 
 		/* remove the components if they are already present and re-add them */
-		while ((comp_data = search_by_id_and_client (priv, NULL,
+		while ((comp_data = search_by_id_and_client (priv, client,
 							      id))) {
 			int pos;
 
 			pos = get_position_in_array (priv->objects, comp_data);
 			e_table_model_row_deleted (E_TABLE_MODEL (model), pos);
 
- 			g_ptr_array_remove (priv->objects, comp_data);
- 			e_cal_model_free_component_data (comp_data);
+ 			if (g_ptr_array_remove (priv->objects, comp_data))
+	 			e_cal_model_free_component_data (comp_data);
  		}
 
 		e_cal_component_free_id (id);
@@ -1394,11 +1408,7 @@ e_cal_view_objects_added_cb (ECalView *query, GList *objects, gpointer user_data
 static void
 e_cal_view_objects_modified_cb (ECalView *query, GList *objects, gpointer user_data)
 {
-	ECalModelPrivate *priv;
 	ECalModel *model = (ECalModel *) user_data;
-	GList *l;
-	
-	priv = model->priv;
 
 	/* now re-add all objects */
 	e_cal_view_objects_added_cb (query, objects, model);
@@ -1412,7 +1422,7 @@ e_cal_view_objects_removed_cb (ECalView *query, GList *ids, gpointer user_data)
 	GList *l;
 	
 	priv = model->priv;
-
+	
 	for (l = ids; l; l = l->next) {
 		ECalModelComponent *comp_data = NULL;
 		ECalComponentId *id = l->data;
@@ -1425,8 +1435,8 @@ e_cal_view_objects_removed_cb (ECalView *query, GList *ids, gpointer user_data)
 			pos = get_position_in_array (priv->objects, comp_data);
 			e_table_model_row_deleted (E_TABLE_MODEL (model), pos);
 
-			g_ptr_array_remove (priv->objects, comp_data);
-			e_cal_model_free_component_data (comp_data);
+			if (g_ptr_array_remove (priv->objects, comp_data))
+				e_cal_model_free_component_data (comp_data);
 		}
 	}
 }
@@ -1580,14 +1590,11 @@ add_new_client (ECalModel *model, ECal *client, gboolean do_query)
 void
 e_cal_model_add_client (ECalModel *model, ECal *client)
 {
-	ECalModelPrivate *priv;
 	ECalModelClient *client_data;
-	
+
 	g_return_if_fail (E_IS_CAL_MODEL (model));
 	g_return_if_fail (E_IS_CAL (client));
-
-	priv = model->priv;
-
+	/* Check this return value or drop the assignment? */
 	client_data = add_new_client (model, client, TRUE);	
 }
 
@@ -1646,14 +1653,11 @@ remove_client (ECalModel *model, ECalModelClient *client_data)
 void
 e_cal_model_remove_client (ECalModel *model, ECal *client)
 {
-	ECalModelPrivate *priv;
 	ECalModelClient *client_data;
 	
 	g_return_if_fail (E_IS_CAL_MODEL (model));
 	g_return_if_fail (E_IS_CAL (client));
 
-	priv = model->priv;
-
 	client_data = find_client_data (model, client);
 	if (client_data)
 		remove_client (model, client_data);
@@ -2081,14 +2085,24 @@ e_cal_model_get_object_array (ECalModel *model)
 void
 e_cal_model_set_instance_times (ECalModelComponent *comp_data, icaltimezone *zone)
 {
-	struct icaltimetype recur_time, start_time, end_time;
+	struct icaltimetype start_time, end_time;
 
-	recur_time = icalcomponent_get_recurrenceid (comp_data->icalcomp);
 	start_time = icalcomponent_get_dtstart (comp_data->icalcomp);
 	end_time = icalcomponent_get_dtend (comp_data->icalcomp);
 
+	if (start_time.is_date && end_time.is_date && (icaltime_compare_date_only (start_time, end_time) == 0)) {
+		/* If both DTSTART and DTEND are DATE values, and they are the
+		   same day, we add 1 day to DTEND. This means that most
+		   events created with the old Evolution behavior will still
+		   work OK. */
+		icaltime_adjust (&end_time, 1, 0, 0, 0);
+		icalcomponent_set_dtend (comp_data->icalcomp, end_time);
+	}
+
+	if (start_time.zone)
+		zone = start_time.zone;
+	
 	comp_data->instance_start = icaltime_as_timet_with_zone (start_time, zone);
 
-	comp_data->instance_end = comp_data->instance_start +
-		(icaltime_as_timet_with_zone (end_time, zone) - icaltime_as_timet_with_zone (start_time, zone));
+	comp_data->instance_end = icaltime_as_timet_with_zone (end_time, zone);
 }
