@@ -33,6 +33,8 @@
 
 #include <sys/stat.h>
 #include <unistd.h>
+#include <glib.h>
+#include <glib/gstdio.h>
 #include <gnome.h>
 #include <misc/e-gui-utils.h>
 #include <table/e-cell-checkbox.h>
@@ -111,16 +113,14 @@ static GdkPixbuf* icon_pixbufs[E_CALENDAR_MODEL_NUM_ICONS] = { 0 };
 
 static GdkAtom clipboard_atom = GDK_NONE;
 
-G_DEFINE_TYPE (ECalendarTable, e_calendar_table, GTK_TYPE_TABLE);
+G_DEFINE_TYPE (ECalendarTable, e_calendar_table, GTK_TYPE_TABLE)
 
 static void
 e_calendar_table_class_init (ECalendarTableClass *class)
 {
 	GtkObjectClass *object_class;
-	GtkWidgetClass *widget_class;
 
 	object_class = (GtkObjectClass *) class;
-	widget_class = (GtkWidgetClass *) class;
 
 	/* Method override */
 	object_class->destroy		= e_calendar_table_destroy;
@@ -459,7 +459,7 @@ e_calendar_table_init (ECalendarTable *cal_table)
 	strings = g_list_append (strings, (char*) _("Not Started"));
 	strings = g_list_append (strings, (char*) _("In Progress"));
 	strings = g_list_append (strings, (char*) _("Completed"));
-	strings = g_list_append (strings, (char*) _("Cancelled"));
+	strings = g_list_append (strings, (char*) _("Canceled"));
 	e_cell_combo_set_popdown_strings (E_CELL_COMBO (popup_cell),
 					  strings);
 
@@ -522,7 +522,7 @@ e_calendar_table_init (ECalendarTable *cal_table)
 
 	a11y = gtk_widget_get_accessible ((GtkWidget *)e_table);
 	if (a11y)
-		atk_object_set_name (a11y, _("Task Table"));
+		atk_object_set_name (a11y, _("Tasks"));
 }
 
 
@@ -1039,7 +1039,7 @@ e_calendar_table_on_save_as (EPopup *ep, EPopupItem *pitem, void *data)
 		return;
 	}
 	
-	file = fopen (filename, "w");
+	file = g_fopen (filename, "w");
 	if (file == NULL) {
 		g_warning ("Couldn't save item");
 		return;
@@ -1187,7 +1187,7 @@ static EPopupItem tasks_popup_items [] = {
 	{ E_POPUP_ITEM, "80.assign", N_("_Assign Task"), e_calendar_table_on_assign, NULL, NULL, E_CAL_POPUP_SELECT_ONE, E_CAL_POPUP_SELECT_EDITABLE|E_CAL_POPUP_SELECT_ASSIGNABLE },
 	{ E_POPUP_ITEM, "90.forward", N_("_Forward as iCalendar"), e_calendar_table_on_forward, NULL, "stock_mail-forward", E_CAL_POPUP_SELECT_ONE },
 	{ E_POPUP_ITEM, "a0.markonecomplete", N_("_Mark as Complete"), mark_as_complete_cb, NULL, NULL, E_CAL_POPUP_SELECT_ONE, E_CAL_POPUP_SELECT_EDITABLE | E_CAL_POPUP_SELECT_NOTCOMPLETE},
-	{ E_POPUP_ITEM, "b0.markmanycomplete", N_("_Mark Selected Tasks as Complete"), mark_as_complete_cb, NULL, NULL, E_CAL_POPUP_SELECT_MANY, E_CAL_POPUP_SELECT_EDITABLE },
+	{ E_POPUP_ITEM, "b0.markmanycomplete", N_("_Mark Selected Tasks as Complete"), mark_as_complete_cb, NULL, NULL, E_CAL_POPUP_SELECT_MANY, E_CAL_POPUP_SELECT_EDITABLE | E_CAL_POPUP_SELECT_NOTCOMPLETE },
 
 	{ E_POPUP_BAR, "c0.bar" },
 
@@ -1376,7 +1376,7 @@ e_calendar_table_load_state	(ECalendarTable *cal_table,
 
 	g_return_if_fail (E_IS_CALENDAR_TABLE (cal_table));
 
-	if (stat (filename, &st) == 0 && st.st_size > 0
+	if (g_stat (filename, &st) == 0 && st.st_size > 0
 	    && S_ISREG (st.st_mode)) {
 		e_table_load_state (e_table_scrolled_get_table (E_TABLE_SCROLLED (cal_table->etable)), filename);
 	}
