@@ -91,8 +91,8 @@ struct _EMFolderTreePrivate {
 	gboolean (*excluded_func)(EMFolderTree *emft, GtkTreeModel *model, GtkTreeIter *iter, void *data);
 	void *excluded_data;
 
-	int do_multiselect:1;	/* multiple select mode */
-	int cursor_set:1;	/* set to TRUE means we or something
+	guint do_multiselect:1;	/* multiple select mode */
+	guint cursor_set:1;	/* set to TRUE means we or something
 				 * else has set the cursor, otherwise
 				 * we need to set it when we set the
 				 * selection */
@@ -1155,15 +1155,15 @@ emft_drop_target(EMFolderTree *emft, GdkDragContext *context, GtkTreePath *path)
 	/* Check for special sources, and vfolder stuff */
 	if (src_uri) {
 		CamelURL *url;
-		char *path;
+		char *url_path;
 		
 		/* FIXME: this is a total hack, but i think all we can do at present */
 		/* Check for dragging from special folders which can't be moved/copied */
 		url = camel_url_new(src_uri, NULL);
-		path = url->fragment?url->fragment:url->path;
-		if (path && path[0]) {
+		url_path = url->fragment?url->fragment:url->path;
+		if (url_path && url_path[0]) {
 			/* don't allow moving any of the the local special folders */
-			if (sstore == local && is_special_local_folder (path)) {
+			if (sstore == local && is_special_local_folder (url_path)) {
 				GdkAtom xfolder;
 				
 				camel_url_free (url);
@@ -1184,16 +1184,16 @@ emft_drop_target(EMFolderTree *emft, GdkDragContext *context, GtkTreePath *path)
 			}
 			
 			/* don't allow copying/moving of the UNMATCHED vfolder */
-			if (!strcmp (url->protocol, "vfolder") && !strcmp (path, CAMEL_UNMATCHED_NAME)) {
+			if (!strcmp (url->protocol, "vfolder") && !strcmp (url_path, CAMEL_UNMATCHED_NAME)) {
 				camel_url_free (url);
 				goto done;
 			}
 			
 			/* don't allow copying/moving of any vTrash/vJunk folder nor maildir 'inbox' */
-			if (strcmp(path, CAMEL_VTRASH_NAME) == 0
-			    || strcmp(path, CAMEL_VJUNK_NAME) == 0
+			if (strcmp(url_path, CAMEL_VTRASH_NAME) == 0
+			    || strcmp(url_path, CAMEL_VJUNK_NAME) == 0
 			    /* Dont allow drag from maildir 'inbox' */
-			    || strcmp(path, ".") == 0) {
+			    || strcmp(url_path, ".") == 0) {
 				camel_url_free(url);
 				goto done;
 			}
@@ -1725,7 +1725,7 @@ emft_get_folder_info__got (struct _mail_msg *mm)
 	gtk_tree_model_get_iter ((GtkTreeModel *) model, &root, path);
 
 	/* if we had an error, then we need to re-set the load subdirs state and collapse the node */
-	if (camel_exception_is_set(&mm->ex)) {
+	if (!m->fi && camel_exception_is_set(&mm->ex)) {
 		gtk_tree_store_set(model, &root, COL_BOOL_LOAD_SUBDIRS, TRUE, -1);
 		gtk_tree_view_collapse_row (priv->treeview, path);
 		gtk_tree_path_free (path);
@@ -2012,6 +2012,12 @@ emft_popup_rename_folder (EPopup *ep, EPopupItem *pitem, void *data)
 	}
 }
 
+static void
+emft_popup_empty_trash (EPopup *ep, EPopupItem *pitem, void *data)
+{
+	em_utils_empty_trash (data);
+}
+
 static void
 emft_popup_properties (EPopup *ep, EPopupItem *pitem, void *data)
 {
@@ -2051,6 +2057,7 @@ static EPopupItem emft_popup_items[] = {
 	{ E_POPUP_BAR, "80.emc" },
 	{ E_POPUP_ITEM, "80.emc.00", N_("_Properties"), emft_popup_properties, NULL, "stock_folder-properties", 0, EM_POPUP_FOLDER_FOLDER|EM_POPUP_FOLDER_SELECT }
 };
+static EPopupItem trash_popup_item = {E_POPUP_ITEM, "20.emc.03", N_("_Empty Trash"), emft_popup_empty_trash,NULL,NULL, 1, EM_POPUP_FOLDER_FOLDER|EM_POPUP_FOLDER_SELECT};
 
 static void
 emft_popup_free(EPopup *ep, GSList *items, void *data)
@@ -2070,6 +2077,7 @@ emft_popup (EMFolderTree *emft, GdkEvent *event)
 	GSList *menus = NULL;
 	guint32 info_flags = 0;
 	guint32 flags = 0;
+	guint32 folder_type_flags = 0;
 	gboolean isstore;
 	char *uri, *full_name;
 	GtkMenu *menu;
@@ -2088,7 +2096,7 @@ emft_popup (EMFolderTree *emft, GdkEvent *event)
 	
 	gtk_tree_model_get (model, &iter, COL_POINTER_CAMEL_STORE, &store,
 			    COL_STRING_URI, &uri, COL_STRING_FULL_NAME, &full_name,
-			    COL_BOOL_IS_STORE, &isstore, -1);
+			    COL_BOOL_IS_STORE, &isstore, COL_UINT_FLAGS, &folder_type_flags, -1);
 
 	/* Stores have full_name == NULL, otherwise its just a placeholder */
 	/* NB: This is kind of messy */
@@ -2129,6 +2137,9 @@ emft_popup (EMFolderTree *emft, GdkEvent *event)
 	for (i = 0; i < sizeof (emft_popup_items) / sizeof (emft_popup_items[0]); i++)
 		menus = g_slist_prepend (menus, &emft_popup_items[i]);
 	
+	if ((folder_type_flags & CAMEL_FOLDER_TYPE_MASK) == CAMEL_FOLDER_TYPE_TRASH)
+		menus = g_slist_prepend (menus, &trash_popup_item);
+
 	e_popup_add_items ((EPopup *)emp, menus, NULL, emft_popup_free, emft);
 
 	menu = e_popup_create_menu_once ((EPopup *)emp, (EPopupTarget *)target, 0);
