@@ -51,6 +51,7 @@
 #include <gtk/gtkarrow.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkentry.h>
+#include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtktogglebutton.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtkmenu.h>
@@ -189,6 +190,7 @@ static void efhd_format_source(EMFormat *, CamelStream *, CamelMimePart *);
 static void efhd_format_attachment(EMFormat *, CamelStream *, CamelMimePart *, const char *, const EMFormatHandler *);
 static void efhd_format_secure(EMFormat *emf, CamelStream *stream, CamelMimePart *part, CamelCipherValidity *valid);
 static void efhd_complete(EMFormat *);
+gboolean efhd_mnemonic_show_bar (GtkWidget *widget, gboolean focus, GtkWidget *efhd);
 
 static gboolean efhd_bonobo_object(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *pobject);
 static gboolean efhd_use_component(const char *mime_type);
@@ -920,6 +922,7 @@ efhd_xpkcs7mime_validity_clicked(GtkWidget *button, EMFormatHTMLPObject *pobject
 		w = gtk_label_new(po->valid->sign.description);
 		gtk_misc_set_alignment((GtkMisc *)w, 0.0, 0.5);
 		gtk_label_set_line_wrap((GtkLabel *)w, FALSE);
+		gtk_label_set_selectable((GtkLabel *)w, TRUE);
 		gtk_box_pack_start((GtkBox *)vbox, w, TRUE, TRUE, 6);
 	}
 
@@ -937,6 +940,7 @@ efhd_xpkcs7mime_validity_clicked(GtkWidget *button, EMFormatHTMLPObject *pobject
 		w = gtk_label_new(po->valid->encrypt.description);
 		gtk_misc_set_alignment((GtkMisc *)w, 0.0, 0.5);
 		gtk_label_set_line_wrap((GtkLabel *)w, FALSE);
+		gtk_label_set_selectable((GtkLabel *)w, TRUE);
 		gtk_box_pack_start((GtkBox *)vbox, w, TRUE, TRUE, 6);
 	}
 
@@ -1660,7 +1664,7 @@ efhd_attachment_button(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObje
 	gtk_container_add((GtkContainer *)button, gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_NONE));
 
 	a11y = gtk_widget_get_accessible (button);
-	atk_object_set_name (a11y, _("Attachment Button"));
+	atk_object_set_name (a11y, _("Attachment"));
 
 	g_signal_connect(button, "button_press_event", G_CALLBACK(efhd_attachment_popup), info);
 	g_signal_connect(button, "popup_menu", G_CALLBACK(efhd_attachment_popup_menu), info);
@@ -1914,7 +1918,7 @@ efhd_bar_save_selected(EPopup *ep, EPopupItem *item, void *data)
 
 static EPopupItem efhd_bar_menu_items[] = {
 	{ E_POPUP_BAR, "05.display", },
-	{ E_POPUP_ITEM, "05.display.01", N_("Save Selected..."), efhd_bar_save_selected, NULL, NULL, EM_POPUP_ATTACHMENTS_MULTIPLE},
+	{ E_POPUP_ITEM, "05.display.01", N_("_Save Selected..."), efhd_bar_save_selected, NULL, NULL, EM_POPUP_ATTACHMENTS_MULTIPLE},
 };
 
 static gboolean
@@ -2033,7 +2037,7 @@ efhd_bar_scroll_event(GtkWidget *w, GdkEventScroll *event, EMFormatHTMLDisplay *
 gboolean 
 efhd_mnemonic_show_bar (GtkWidget *widget, gboolean focus, GtkWidget *efhd)
 {
-	attachment_bar_arrow_clicked (NULL, efhd);
+	attachment_bar_arrow_clicked (NULL, (EMFormatHTMLDisplay *)efhd);
 
 	return TRUE;
 }
@@ -2048,7 +2052,7 @@ efhd_add_bar(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *pobjec
 
 	priv->attachment_bar = e_attachment_bar_new(NULL);
 	scroll = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_policy (scroll, GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	((EAttachmentBar *)priv->attachment_bar)->expand = TRUE;
 	
 	priv->forward = gtk_arrow_new(GTK_ARROW_RIGHT, GTK_SHADOW_NONE);
@@ -2058,10 +2062,10 @@ efhd_add_bar(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *pobjec
 	gtk_box_pack_start ((GtkBox *)hbox3, priv->down, FALSE, FALSE, 0);
 	priv->arrow = (GtkWidget *)gtk_tool_button_new(hbox3, NULL);
 	g_signal_connect (priv->arrow, "mnemonic_activate", G_CALLBACK (efhd_mnemonic_show_bar), efh);
-	atk_object_set_name (gtk_widget_get_accessible (priv->arrow), _("Toggle Attachment Bar"));
+	atk_object_set_name (gtk_widget_get_accessible (priv->arrow), _("Show Attachments"));
 
 	priv->label = gtk_label_new(_("No Attachment"));
-	gtk_label_set_mnemonic_widget (priv->label, priv->arrow);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (priv->label), priv->arrow);
 	save = gtk_button_new();
 	image = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_BUTTON);
 	txt = gtk_label_new_with_mnemonic(_("S_ave"));
@@ -2078,7 +2082,7 @@ efhd_add_bar(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *pobjec
 	gtk_box_pack_start ((GtkBox *)hbox2, save, FALSE, FALSE, 2);
 
 	priv->attachment_box = scroll;
-	gtk_scrolled_window_set_shadow_type (scroll, GTK_SHADOW_IN);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll), GTK_SHADOW_IN);
 	gtk_container_add ((GtkContainer *)priv->attachment_box, priv->attachment_bar);
 
 	gtk_widget_get_size_request(priv->attachment_bar, &width, &height);
