@@ -54,6 +54,8 @@
 #include <gtk/gtkoptionmenu.h>
 #include <gtk/gtkmenuitem.h>
 
+#include "e-util/e-util-private.h"
+
 #include "mail-config.h"
 #include "em-config.h"
 
@@ -719,8 +721,14 @@ em_mailer_prefs_construct (EMMailerPrefs *prefs)
 	EMConfig *ec;
 	EMConfigTargetPrefs *target;
 	GSList *l;
+	char *gladefile;
+
+	gladefile = g_build_filename (EVOLUTION_GLADEDIR,
+				      "mail-config.glade",
+				      NULL);
+	gui = glade_xml_new (gladefile, "preferences_toplevel", NULL);
+	g_free (gladefile);
 
-	gui = glade_xml_new (EVOLUTION_GLADEDIR "/mail-config.glade", "preferences_toplevel", NULL);
 	prefs->gui = gui;
 
 	/** @HookPoint-EMConfig: Mail Preferences Page
@@ -811,6 +819,7 @@ em_mailer_prefs_construct (EMMailerPrefs *prefs)
 	font = gconf_client_get_string (prefs->gconf, "/apps/evolution/mail/display/fonts/monospace", NULL);
 	prefs->font_fixed = GNOME_FONT_PICKER (glade_xml_get_widget (gui, "FontFixed"));
 	gnome_font_picker_set_font_name (prefs->font_fixed, font);
+	g_free (font);
 	g_object_set_data ((GObject *) prefs->font_fixed, "key", "/apps/evolution/mail/display/fonts/monospace");
 	g_signal_connect (prefs->font_fixed, "font-set", G_CALLBACK (font_changed), prefs);
 	if (!gconf_client_key_is_writable (prefs->gconf, "/apps/evolution/mail/display/fonts/monospace", NULL))
