@@ -129,6 +129,7 @@ kill_dataserver (void)
 	system (KILL_PROCESS_CMD " -9 lt-evolution-data-server 2> /dev/null");
 	system (KILL_PROCESS_CMD " -9 evolution-data-server-1.0 2> /dev/null");
 	system (KILL_PROCESS_CMD " -9 evolution-data-server-1.2 2> /dev/null");
+	system (KILL_PROCESS_CMD " -9 evolution-data-server-1.4 2> /dev/null");
 
 	system (KILL_PROCESS_CMD " -9 lt-evolution-alarm-notify 2> /dev/null");
 	system (KILL_PROCESS_CMD " -9 evolution-alarm-notify 2> /dev/null");
@@ -463,6 +464,9 @@ setup_segv_redirect (void)
 int
 main (int argc, char **argv)
 {
+#ifdef G_OS_WIN32
+	extern void link_shutdown (void);
+#endif
 	struct poptOption options[] = {
 		{ "component", 'c', POPT_ARG_STRING, &default_component_id, 0,
 		  N_("Start Evolution activating the specified component"), NULL },
@@ -526,6 +530,10 @@ main (int argc, char **argv)
 		exit (0);
 	}
 
+#ifdef G_OS_WIN32
+	gtk_rc_parse_string ("gtk-fallback-icon-theme = \"gnome\"");
+#endif
+
 #if DEVELOPMENT
 	if (force_migrate) {
 		destroy_config ();
@@ -606,6 +614,8 @@ main (int argc, char **argv)
 	g_object_unref (program);
 	gnome_sound_shutdown ();
 	e_cursors_shutdown ();
-	
+#ifdef G_OS_WIN32
+	link_shutdown ();
+#endif
 	return 0;
 }
