@@ -318,7 +318,7 @@ e_date_edit_new			(void)
 
 	dedit = g_object_new (E_TYPE_DATE_EDIT, NULL);
 	a11y = gtk_widget_get_accessible (GTK_WIDGET (dedit));
-	atk_object_set_name (a11y, _("Date and Time Entry"));
+	atk_object_set_name (a11y, _("Date and Time"));
 
 	return GTK_WIDGET (dedit);
 }
@@ -338,7 +338,7 @@ create_children			(EDateEdit	*dedit)
 	priv->date_entry  = gtk_entry_new ();
 	a11y = gtk_widget_get_accessible (priv->date_entry);
 	atk_object_set_description (a11y, _("Text entry to input date"));
-	atk_object_set_name (a11y, _("Text Date Entry"));
+	atk_object_set_name (a11y, _("Date"));
 	gtk_box_pack_start (GTK_BOX (dedit), priv->date_entry, FALSE, TRUE, 0);
 	gtk_widget_set_size_request (priv->date_entry, 100, -1);
 	
@@ -360,7 +360,7 @@ create_children			(EDateEdit	*dedit)
 			    FALSE, FALSE, 0);
 	a11y = gtk_widget_get_accessible (priv->date_button);
 	atk_object_set_description (a11y, _("Click this button to show a calendar"));
-	atk_object_set_name (a11y, _("Date Button"));
+	atk_object_set_name (a11y, _("Date"));
 
 	arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_NONE);
 	gtk_container_add (GTK_CONTAINER (priv->date_button), arrow);
@@ -382,7 +382,7 @@ create_children			(EDateEdit	*dedit)
 	rebuild_time_popup (dedit);
 	a11y = gtk_widget_get_accessible (priv->time_combo);
 	atk_object_set_description (a11y, _("Combo box to select time"));
-	atk_object_set_name (a11y, _("Time Combo Box"));
+	atk_object_set_name (a11y, _("Time"));
 
 	g_signal_connect (GTK_COMBO (priv->time_combo)->entry,
 			  "key_press_event",
@@ -715,13 +715,10 @@ e_date_edit_set_date		(EDateEdit	*dedit,
 				 gint		 month,
 				 gint		 day)
 {
-	EDateEditPrivate *priv;
 	gboolean date_changed = FALSE;
 
 	g_return_if_fail (E_IS_DATE_EDIT (dedit));
 
-	priv = dedit->priv;
-
 	date_changed = e_date_edit_set_date_internal (dedit, TRUE, FALSE,
 						      year - 1900, month - 1,
 						      day);
@@ -822,13 +819,10 @@ e_date_edit_set_date_and_time_of_day       (EDateEdit      *dedit,
 					    gint            hour,
 					    gint            minute)
 {
-	EDateEditPrivate *priv;
 	gboolean date_changed, time_changed;
 
 	g_return_if_fail (E_IS_DATE_EDIT (dedit));
 
-	priv = dedit->priv;
-
 	date_changed = e_date_edit_set_date_internal (dedit, TRUE, FALSE,
 						      year - 1900, month - 1, day);
 	time_changed = e_date_edit_set_time_internal (dedit, TRUE, FALSE,
@@ -1267,11 +1261,8 @@ static void
 on_date_popup_date_selected	(ECalendarItem	*calitem,
 				 EDateEdit	*dedit)
 {
-	EDateEditPrivate *priv;
 	GDate start_date, end_date;
 
-	priv = dedit->priv;
-
 	hide_date_popup (dedit);
 
 	if (!e_calendar_item_get_selection (calitem, &start_date, &end_date))
@@ -1625,7 +1616,7 @@ on_date_entry_focus_out			(GtkEntry	*entry,
 					 EDateEdit	*dedit)
 {
 	struct tm tmp_tm;
-	GtkMessageDialog *msg_dialog;
+	GtkWidget *msg_dialog;
 
 	tmp_tm.tm_year = 0;
         tmp_tm.tm_mon = 0;
@@ -1643,7 +1634,7 @@ on_date_entry_focus_out			(GtkEntry	*entry,
 		gtk_widget_destroy (msg_dialog);
 		e_date_edit_get_date (dedit,&tmp_tm.tm_year,&tmp_tm.tm_mon,&tmp_tm.tm_mday);
 		e_date_edit_set_date (dedit,tmp_tm.tm_year,tmp_tm.tm_mon,tmp_tm.tm_mday);
-		gtk_widget_grab_focus (entry);		
+		gtk_widget_grab_focus (GTK_WIDGET (entry));		
 		return FALSE;
 	}
 	return FALSE;
@@ -1655,7 +1646,7 @@ on_time_entry_focus_out			(GtkEntry	*entry,
 					 GdkEventFocus  *event,
 					 EDateEdit	*dedit)
 {
-	GtkMessageDialog *msg_dialog;
+	GtkWidget *msg_dialog;
 	
 	e_date_edit_check_time_changed (dedit);
 
@@ -1668,7 +1659,7 @@ on_time_entry_focus_out			(GtkEntry	*entry,
 		gtk_dialog_run (GTK_DIALOG(msg_dialog));
 		gtk_widget_destroy (msg_dialog);
 		e_date_edit_set_time (dedit,e_date_edit_get_time(dedit));
-		gtk_widget_grab_focus (entry);
+		gtk_widget_grab_focus (GTK_WIDGET (entry));
 		return FALSE;
 	}
 	return FALSE;
@@ -1732,9 +1723,9 @@ e_date_edit_update_date_entry		(EDateEdit	*dedit)
 		tmp_tm.tm_mday = priv->day;
 		tmp_tm.tm_isdst = -1;
 
-		/* This is a strftime() format for a short date. %m = month,
-		   %d = day of month, %Y = year (all digits). */
-		e_utf8_strftime (buffer, sizeof (buffer), _("%m/%d/%Y"), &tmp_tm);
+		/* This is a strftime() format for a short date. 
+		   %x the preferred date representation for the current locale without the time*/
+		e_utf8_strftime (buffer, sizeof (buffer), "%x", &tmp_tm);
 		gtk_entry_set_text (GTK_ENTRY (priv->date_entry), buffer);
 	}
 
